@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2010, 2011, 2012, 2014, 2015, 2016, 2019 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "board.h"
 
@@ -45,11 +32,9 @@
 #include <QXmlStreamWriter>
 
 #include <algorithm>
-#include <random>
 
 #include <cmath>
 #include <cstdlib>
-#include <ctime>
 
 //-----------------------------------------------------------------------------
 
@@ -67,41 +52,44 @@ int powerOfTwo(int value)
 
 namespace
 {
-	struct PieceDetails
-	{
-		QPoint pos;
-		int rotation;
-		QList<Tile*> tiles;
 
-		PieceDetails(const QPoint& pos_, int rotation_, const QList<Tile*>& tiles_)
-			: pos(pos_), rotation(rotation_), tiles(tiles_)
-		{
-		}
-	};
+struct PieceDetails
+{
+	QPoint pos;
+	int rotation;
+	QList<Tile*> tiles;
+
+	PieceDetails(const QPoint& pos_, int rotation_, const QList<Tile*>& tiles_)
+		: pos(pos_), rotation(rotation_), tiles(tiles_)
+	{
+	}
+};
+
 }
 
 //-----------------------------------------------------------------------------
 
-Board::Board(QWidget* parent) :
-	QOpenGLWidget(parent),
-	m_id(0),
-	m_load_bevels(true),
-	m_has_bevels(true),
-	m_has_shadows(true),
-	m_image(nullptr),
-	m_image_ts(0),
-	m_columns(0),
-	m_rows(0),
-	m_total_pieces(0),
-	m_completed(0),
-	m_pos(0, 0),
-	m_scale_level(9),
-	m_scale(0),
-	m_scrolling(false),
-	m_selecting(false),
-	m_finished(false),
-	m_action_key(0),
-	m_action_button(Qt::NoButton)
+Board::Board(QWidget* parent)
+	: QOpenGLWidget(parent)
+	, m_id(0)
+	, m_load_bevels(true)
+	, m_has_bevels(true)
+	, m_has_shadows(true)
+	, m_image(nullptr)
+	, m_image_ts(0)
+	, m_columns(0)
+	, m_rows(0)
+	, m_total_pieces(0)
+	, m_completed(0)
+	, m_pos(0, 0)
+	, m_scale_level(9)
+	, m_scale(0)
+	, m_scrolling(false)
+	, m_selecting(false)
+	, m_finished(false)
+	, m_action_key(0)
+	, m_action_button(Qt::NoButton)
+	, m_random(QRandomGenerator::securelySeeded())
 {
 	setFocusPolicy(Qt::StrongFocus);
 	setFocus();
@@ -123,7 +111,7 @@ Board::~Board()
 	delete m_shadow_image;
 	delete m_message;
 	delete graphics_layer;
-	graphics_layer = 0;
+	graphics_layer = nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -145,7 +133,7 @@ void Board::removePiece(Piece* piece)
 {
 	m_pieces.removeAll(piece);
 	delete piece;
-	piece = 0;
+	piece = nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -160,7 +148,7 @@ void Board::setAppearance(const AppearanceDialog& dialog)
 	QPalette palette = dialog.colors();
 	graphics_layer->setClearColor(palette.color(QPalette::Base).darker(150));
 	setPalette(palette);
-	for (Piece* piece : m_pieces) {
+	for (Piece* piece : qAsConst(m_pieces)) {
 		piece->setSelected(piece->isSelected());
 	}
 }
@@ -183,7 +171,7 @@ void Board::newGame(const QString& image, int difficulty)
 	zoom(0);
 
 	// Prevent starting a game with a missing image
-	if (!QFileInfo(Path::image(image)).exists()) {
+	if (!QFileInfo::exists(Path::image(image))) {
 		QMessageBox::warning(this, tr("Error"), tr("Missing image."));
 		return;
 	}
@@ -196,7 +184,8 @@ void Board::newGame(const QString& image, int difficulty)
 
 	// Generate ID
 	m_id = 0;
-	for (const QString& file : QDir(Path::saves()).entryList(QDir::Files)) {
+	const QStringList files = QDir(Path::saves()).entryList(QDir::Files);
+	for (const QString& file : files) {
 		m_id = std::max(m_id, file.section(".", 0, 0).toInt());
 	}
 	m_id++;
@@ -220,14 +209,8 @@ void Board::newGame(const QString& image, int difficulty)
 
 	// Generate puzzle
 	updateStatusMessage(tr("Generating puzzle..."));
-#ifndef Q_OS_WIN
-	std::random_device rd;
-	m_random.seed(rd());
-#else
-	m_random.seed(time(0));
-#endif
 	Generator generator(m_columns, m_rows, m_random);
-	QList< QList<Tile*> > pieces = generator.pieces();
+	QList<QList<Tile*>> pieces = generator.pieces();
 	std::shuffle(pieces.begin(), pieces.end(), m_random);
 
 	updateStatusMessage(tr("Creating pieces..."));
@@ -290,18 +273,18 @@ void Board::openGame(int id)
 	QXmlStreamAttributes attributes = xml.attributes();
 	int board_zoom = 0;
 	QRect rect;
-	unsigned int version = attributes.value("version").toString().toUInt();
+	unsigned int version = attributes.value("version").toUInt();
 	if (xml.name() == QLatin1String("tetzle") && version <= 5) {
 		m_image_path = attributes.value("image").toString();
-		if (!QFileInfo(Path::image(m_image_path)).exists()) {
+		if (!QFileInfo::exists(Path::image(m_image_path))) {
 			QApplication::restoreOverrideCursor();
 			QMessageBox::warning(this, tr("Error"), tr("Missing image."));
 			cleanup();
 			return;
 		}
-		board_zoom = attributes.value("zoom").toString().toInt();
-		m_pos.setX(attributes.value("x").toString().toInt());
-		m_pos.setY(attributes.value("y").toString().toInt());
+		board_zoom = attributes.value("zoom").toInt();
+		m_pos.setX(attributes.value("x").toInt());
+		m_pos.setY(attributes.value("y").toInt());
 		QStringList values = attributes.value("rect").toString().split(",");
 		rect.setRect(values.value(0).toInt(),
 			values.value(1). toInt(),
@@ -333,14 +316,14 @@ void Board::openGame(int id)
 			attributes = xml.attributes();
 			if (!piece) {
 				piece = true;
-				pos = QPoint(attributes.value("x").toString().toInt(), attributes.value("y").toString().toInt());
-				rotation = (rotation != -1) ? rotation : attributes.value("rotation").toString().toInt();
+				pos = QPoint(attributes.value("x").toInt(), attributes.value("y").toInt());
+				rotation = (rotation != -1) ? rotation : attributes.value("rotation").toInt();
 			}
-			int column = attributes.value("column").toString().toInt();
+			int column = attributes.value("column").toInt();
 			m_columns = std::max(m_columns, column);
-			int row = attributes.value("row").toString().toInt();
+			int row = attributes.value("row").toInt();
 			m_rows = std::max(m_rows, row);
-			int bevel = attributes.value("bevel").toString().toInt();
+			int bevel = attributes.value("bevel").toInt();
 			if (bevel) {
 				m_load_bevels = true;
 			}
@@ -349,13 +332,13 @@ void Board::openGame(int id)
 			tiles.append(tile);
 		} else if (xml.name() == QLatin1String("piece")) {
 			attributes = xml.attributes();
-			pos = QPoint(attributes.value("x").toString().toInt(), attributes.value("y").toString().toInt());
-			rotation = attributes.value("rotation").toString().toInt();
+			pos = QPoint(attributes.value("x").toInt(), attributes.value("y").toInt());
+			rotation = attributes.value("rotation").toInt();
 			tiles.clear();
 		} else if (xml.name() == QLatin1String("group")) {
 			piece = false;
-			QStringRef r = xml.attributes().value("rotation");
-			rotation = !r.isEmpty() ? r.toString().toInt() : -1;
+			auto r = xml.attributes().value("rotation");
+			rotation = !r.isEmpty() ? r.toInt() : -1;
 			tiles.clear();
 		} else if (xml.name() != QLatin1String("overview")) {
 			xml.raiseError(tr("Unknown element '%1'").arg(xml.name().toString()));
@@ -436,13 +419,13 @@ void Board::saveGame()
 		.arg(m_scene.width())
 		.arg(m_scene.height()));
 
-	for (Piece* piece : m_pieces) {
+	for (Piece* piece : qAsConst(m_pieces)) {
 		piece->save(xml);
 	}
-	for (Piece* piece : m_selected_pieces) {
+	for (Piece* piece : qAsConst(m_selected_pieces)) {
 		piece->save(xml);
 	}
-	for (Piece* piece : m_active_pieces) {
+	for (Piece* piece : qAsConst(m_active_pieces)) {
 		piece->save(xml);
 	}
 
@@ -471,7 +454,7 @@ void Board::retrievePieces()
 
 	// Move all pieces to center of view
 	std::shuffle(pieces.begin(), pieces.end(), m_random);
-	for (Piece* piece : pieces) {
+	for (Piece* piece : qAsConst(pieces)) {
 		m_pieces.append(piece);
 		piece->setPosition(m_pos - QRect(QPoint(0,0), piece->boundingRect().size()).center());
 		piece->setSelected(false);
@@ -771,6 +754,7 @@ void Board::keyPressEvent(QKeyEvent* event)
 	case Qt::Key_D:
 		moveCursor(QPoint(offset, 0));
 		break;
+
 	default:
 		if (!event->isAutoRepeat()) {
 			m_action_key = event->key();
@@ -798,7 +782,7 @@ void Board::mousePressEvent(QMouseEvent* event)
 	}
 
 	m_action_button = event->button();
-	if (m_action_button == Qt::MidButton || (m_action_button == Qt::LeftButton && m_action_key == Qt::Key_Shift)) {
+	if (m_action_button == Qt::MiddleButton || (m_action_button == Qt::LeftButton && m_action_key == Qt::Key_Shift)) {
 		startScrolling();
 	} else if (m_action_button == Qt::LeftButton) {
 		m_select_pos = event->pos();
@@ -824,7 +808,7 @@ void Board::mouseReleaseEvent(QMouseEvent* event)
 		rotatePiece();
 		break;
 
-	case Qt::MidButton:
+	case Qt::MiddleButton:
 		stopScrolling();
 		break;
 
@@ -992,7 +976,7 @@ void Board::grabPiece()
 	}
 
 	Piece* piece = pieceUnderCursor();
-	if (piece == 0) {
+	if (!piece) {
 		return;
 	}
 	m_active_pieces.append(piece);
@@ -1059,7 +1043,7 @@ void Board::rotatePiece()
 
 	if (m_active_pieces.isEmpty()) {
 		Piece* piece = pieceUnderCursor();
-		if (piece == 0) {
+		if (!piece) {
 			return;
 		}
 		piece->rotate(mapCursorPosition());
@@ -1201,7 +1185,7 @@ void Board::updateCursor()
 {
 	int state = 0;
 	if (!m_finished) {
-		state = (pieceUnderCursor() != 0 || m_selecting) | (!m_active_pieces.isEmpty() * 2);
+		state = (pieceUnderCursor() || m_selecting) | (!m_active_pieces.isEmpty() * 2);
 	}
 
 	switch (state) {
@@ -1280,7 +1264,7 @@ void Board::updateArray(Region& region, const QRect& rect, int z)
 void Board::updateSceneRectangle()
 {
 	m_scene = QRect(0,0,0,0);
-	for (Piece* piece : m_pieces) {
+	for (Piece* piece : qAsConst(m_pieces)) {
 		updateSceneRectangle(piece);
 	}
 }
