@@ -1,24 +1,11 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2010, 2011, 2014, 2016 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2021 Graeme Gott <graeme@gottcode.org>
 
-#ifndef BOARD_H
-#define BOARD_H
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
+
+#ifndef TETZLE_BOARD_H
+#define TETZLE_BOARD_H
 
 #include "graphics_layer.h"
 class AppearanceDialog;
@@ -29,10 +16,9 @@ class Tile;
 
 #include <QHash>
 #include <QOpenGLWidget>
+#include <QRandomGenerator>
 class QOpenGLTexture;
 
-#include <random>
-
 class Board : public QOpenGLWidget
 {
 	Q_OBJECT
@@ -44,7 +30,7 @@ class Board : public QOpenGLWidget
 	};
 
 public:
-	Board(QWidget* parent = 0);
+	explicit Board(QWidget* parent = nullptr);
 	~Board();
 
 	Piece* findCollidingPiece(Piece* piece) const;
@@ -82,15 +68,15 @@ signals:
 	void finished();
 
 protected:
-	virtual void initializeGL();
-	virtual void resizeGL(int w, int h);
-	virtual void paintGL();
-	virtual void keyPressEvent(QKeyEvent* event);
-	virtual void keyReleaseEvent(QKeyEvent* event);
-	virtual void mousePressEvent(QMouseEvent* event);
-	virtual void mouseReleaseEvent(QMouseEvent* event);
-	virtual void mouseMoveEvent(QMouseEvent* event);
-	virtual void wheelEvent(QWheelEvent* event);
+	void initializeGL() override;
+	void resizeGL(int w, int h) override;
+	void paintGL() override;
+	void keyPressEvent(QKeyEvent* event) override;
+	void keyReleaseEvent(QKeyEvent* event) override;
+	void mousePressEvent(QMouseEvent* event) override;
+	void mouseReleaseEvent(QMouseEvent* event) override;
+	void mouseMoveEvent(QMouseEvent* event) override;
+	void wheelEvent(QWheelEvent* event) override;
 
 private:
 	void startScrolling();
@@ -155,7 +141,7 @@ private:
 	int m_action_key;
 	Qt::MouseButton m_action_button;
 
-	std::mt19937 m_random;
+	QRandomGenerator m_random;
 };
 
 
@@ -176,8 +162,7 @@ inline QRect Board::marginRect(const QRect& rect) const
 
 inline int Board::randomInt(int max)
 {
-	std::uniform_int_distribution<int> dis(0, max - 1);
-	return dis(m_random);
+	return m_random.bounded(max);
 }
 
 inline float Board::tileTextureSize() const
@@ -190,4 +175,4 @@ inline const QPointF* Board::corners(int rotation) const
 	return m_corners[rotation];
 }
 
-#endif
+#endif // TETZLE_BOARD_H
