@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2011, 2012, 2014, 2016, 2017, 2018 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2011-2018 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "graphics_layer.h"
 
@@ -29,7 +16,7 @@
 
 //-----------------------------------------------------------------------------
 
-GraphicsLayer* graphics_layer = 0;
+GraphicsLayer* graphics_layer = nullptr;
 
 //-----------------------------------------------------------------------------
 
@@ -159,8 +146,8 @@ void GraphicsLayer::setVersion(int version)
 
 //-----------------------------------------------------------------------------
 
-GraphicsLayer::GraphicsLayer() :
-	m_changed(true)
+GraphicsLayer::GraphicsLayer()
+	: m_changed(true)
 {
 	// Start with a 1MB vertex buffer
 	m_data.resize(0x100000 / sizeof(Vertex));
@@ -268,7 +255,7 @@ void GraphicsLayer::uploadChanged(QOpenGLBuffer* vertex_buffer)
 {
 	const int vertex_size = sizeof(Vertex);
 	if (!m_changed_regions.isEmpty()) {
-		for (const VertexArray& region : m_changed_regions) {
+		for (const VertexArray& region : qAsConst(m_changed_regions)) {
 			vertex_buffer->write(region.start * vertex_size, m_data.constBegin() + region.start, region.length() * vertex_size);
 		}
 		m_changed_regions.clear();
@@ -282,9 +269,9 @@ void GraphicsLayer::uploadChanged(QOpenGLBuffer* vertex_buffer)
 
 //-----------------------------------------------------------------------------
 
-GraphicsLayer21::GraphicsLayer21(QOpenGLVertexArrayObject* vertex_array, const QByteArray& glsl, const QString& shader) :
-	m_program(nullptr),
-	m_vertex_array(vertex_array)
+GraphicsLayer21::GraphicsLayer21(QOpenGLVertexArrayObject* vertex_array, const QByteArray& glsl, const QString& shader)
+	: m_program(nullptr)
+	, m_vertex_array(vertex_array)
 {
 	initializeOpenGLFunctions();
 
