@@ -1,29 +1,18 @@
-/***********************************************************************
- *
- * Copyright (C) 2011, 2012, 2016, 2018 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2011-2018 Graeme Gott <graeme@gottcode.org>
 
-#ifndef GRAPHICS_LAYER_H
-#define GRAPHICS_LAYER_H
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
+
+#ifndef TETZLE_GRAPHICS_LAYER_H
+#define TETZLE_GRAPHICS_LAYER_H
 
 #include <QMatrix4x4>
 #include <QOpenGLFunctions>
+#ifndef QT_OPENGL_ES_2
 #include <QOpenGLFunctions_1_1>
 #include <QOpenGLFunctions_1_3>
+#endif
 class QOpenGLBuffer;
 class QOpenGLShaderProgram;
 class QOpenGLVertexArrayObject;
@@ -56,8 +45,8 @@ struct VertexArray
 	int end;
 
 	VertexArray()
-	:	start(0),
-		end(0)
+		: start(0)
+		, end(0)
 	{
 	}
 
@@ -93,7 +82,7 @@ public:
 	virtual void uploadData()=0;
 
 protected:
-	GraphicsLayer();
+	explicit GraphicsLayer();
 
 protected:
 	void clearChanged();
@@ -120,18 +109,18 @@ public:
 	GraphicsLayer21(QOpenGLVertexArrayObject* vertex_array, const QByteArray& glsl, const QString& shader);
 	~GraphicsLayer21();
 
-	virtual void bindTexture(unsigned int unit, GLuint texture);
-	virtual void clear();
-	virtual void draw(const VertexArray& array, GLenum mode = GL_TRIANGLES);
-	virtual GLint getMaxTextureSize();
-	virtual void setBlended(bool enabled);
-	virtual void setClearColor(const QColor& color);
-	virtual void setColor(const QColor& color);
-	virtual void setModelview(const QMatrix4x4& matrix);
-	virtual void setProjection(const QMatrix4x4& matrix);
-	virtual void setTextureUnits(unsigned int units);
-	virtual void setViewport(GLint x, GLint y, GLsizei width, GLsizei height);
-	virtual void uploadData();
+	void bindTexture(unsigned int unit, GLuint texture) override;
+	void clear() override;
+	void draw(const VertexArray& array, GLenum mode = GL_TRIANGLES) override;
+	GLint getMaxTextureSize() override;
+	void setBlended(bool enabled) override;
+	void setClearColor(const QColor& color) override;
+	void setColor(const QColor& color) override;
+	void setModelview(const QMatrix4x4& matrix) override;
+	void setProjection(const QMatrix4x4& matrix) override;
+	void setTextureUnits(unsigned int units) override;
+	void setViewport(GLint x, GLint y, GLsizei width, GLsizei height) override;
+	void uploadData() override;
 
 private:
 	QOpenGLShaderProgram* loadProgram(unsigned int index, const QByteArray& glsl, const QString& shader);
@@ -163,56 +152,56 @@ private:
 class GraphicsLayer11 : public GraphicsLayer, protected QOpenGLFunctions_1_1
 {
 public:
-	GraphicsLayer11();
+	explicit GraphicsLayer11();
 
-	virtual void bindTexture(unsigned int unit, GLuint texture);
-	virtual void clear();
-	virtual void draw(const VertexArray& array, GLenum mode = GL_TRIANGLES);
-	virtual GLint getMaxTextureSize();
-	virtual void setBlended(bool enabled);
-	virtual void setClearColor(const QColor& color);
-	virtual void setColor(const QColor& color);
-	virtual void setModelview(const QMatrix4x4& matrix);
-	virtual void setProjection(const QMatrix4x4& matrix);
-	virtual void setTextureUnits(unsigned int units);
-	virtual void setViewport(GLint x, GLint y, GLsizei width, GLsizei height);
-	virtual void uploadData();
+	void bindTexture(unsigned int unit, GLuint texture) override;
+	void clear() override;
+	void draw(const VertexArray& array, GLenum mode = GL_TRIANGLES) override;
+	GLint getMaxTextureSize() override;
+	void setBlended(bool enabled) override;
+	void setClearColor(const QColor& color) override;
+	void setColor(const QColor& color) override;
+	void setModelview(const QMatrix4x4& matrix) override;
+	void setProjection(const QMatrix4x4& matrix) override;
+	void setTextureUnits(unsigned int units) override;
+	void setViewport(GLint x, GLint y, GLsizei width, GLsizei height) override;
+	void uploadData() override;
 };
 
 
 class GraphicsLayer13 : public GraphicsLayer, protected QOpenGLFunctions_1_3
 {
 public:
-	GraphicsLayer13();
+	explicit GraphicsLayer13();
 
-	virtual void bindTexture(unsigned int unit, GLuint texture);
-	virtual void clear();
-	virtual void draw(const VertexArray& array, GLenum mode = GL_TRIANGLES);
-	virtual GLint getMaxTextureSize();
-	virtual void setBlended(bool enabled);
-	virtual void setClearColor(const QColor& color);
-	virtual void setColor(const QColor& color);
-	virtual void setModelview(const QMatrix4x4& matrix);
-	virtual void setProjection(const QMatrix4x4& matrix);
-	virtual void setTextureUnits(unsigned int units);
-	virtual void setViewport(GLint x, GLint y, GLsizei width, GLsizei height);
-	virtual void uploadData();
+	void bindTexture(unsigned int unit, GLuint texture) override;
+	void clear() override;
+	void draw(const VertexArray& array, GLenum mode = GL_TRIANGLES) override;
+	GLint getMaxTextureSize() override;
+	void setBlended(bool enabled) override;
+	void setClearColor(const QColor& color) override;
+	void setColor(const QColor& color) override;
+	void setModelview(const QMatrix4x4& matrix) override;
+	void setProjection(const QMatrix4x4& matrix) override;
+	void setTextureUnits(unsigned int units) override;
+	void setViewport(GLint x, GLint y, GLsizei width, GLsizei height) override;
+	void uploadData() override;
 };
 
 
 class GraphicsLayer15 : public GraphicsLayer13
 {
 public:
-	GraphicsLayer15();
+	explicit GraphicsLayer15();
 	~GraphicsLayer15();
 
-	virtual void draw(const VertexArray& array, GLenum mode = GL_TRIANGLES);
-	virtual void setTextureUnits(unsigned int units);
-	virtual void uploadData();
+	void draw(const VertexArray& array, GLenum mode = GL_TRIANGLES) override;
+	void setTextureUnits(unsigned int units) override;
+	void uploadData() override;
 
 private:
 	QOpenGLBuffer* m_vertex_buffer;
 };
 #endif
 
-#endif
+#endif // TETZLE_GRAPHICS_LAYER_H
