@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2018, 2019 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -36,10 +23,10 @@ class Application : public QApplication
 public:
 	Application(int& argc, char** argv);
 
-	void createWindow();
+	void createWindow(const QStringList& files);
 
 protected:
-	virtual bool event(QEvent* e);
+	bool event(QEvent* e) override;
 
 private:
 	QStringList m_files;
@@ -49,8 +36,8 @@ private:
 //-----------------------------------------------------------------------------
 
 Application::Application(int& argc, char** argv)
-	: QApplication(argc, argv),
-	m_window(0)
+	: QApplication(argc, argv)
+	, m_window(nullptr)
 {
 	setApplicationName("Tetzle");
 	setApplicationVersion(VERSIONSTR);
@@ -61,24 +48,15 @@ Application::Application(int& argc, char** argv)
 	setWindowIcon(QIcon::fromTheme("tetzle", QIcon(":/tetzle.png")));
 	setDesktopFileName("tetzle");
 #endif
-	setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
-	m_files = arguments().mid(1);
 	processEvents();
 }
 
 //-----------------------------------------------------------------------------
 
-void Application::createWindow()
+void Application::createWindow(const QStringList& files)
 {
-	// Remove command-line parameters from file list
-	for (int i = 0; i < m_files.size(); ++i) {
-		if (m_files.at(i).startsWith("--")) {
-			m_files.removeAt(i);
-			--i;
-		}
-	}
-
+	m_files += files;
 	m_window = new Window(m_files);
 }
 
@@ -104,6 +82,7 @@ bool Application::event(QEvent* e)
 
 int main(int argc, char** argv)
 {
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
 #if !defined(Q_OS_MAC)
 	if (!qEnvironmentVariableIsSet("QT_DEVICE_PIXEL_RATIO")
 			&& !qEnvironmentVariableIsSet("QT_AUTO_SCREEN_SCALE_FACTOR")
@@ -111,6 +90,8 @@ int main(int argc, char** argv)
 			&& !qEnvironmentVariableIsSet("QT_SCREEN_SCALE_FACTORS")) {
 		QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 	}
+#endif
+	QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
 	Application app(argc, argv);
 
@@ -126,6 +107,7 @@ int main(int argc, char** argv)
 	parser.addOption(QCommandLineOption(QStringList() << "G" << "graphics-layer",
 		QCoreApplication::translate("main", "Select OpenGL version."),
 		QCoreApplication::translate("main", "version")));
+	parser.addPositionalArgument("files", QCoreApplication::translate("main", "Images to add to the choose game dialog."), "[files]");
 	parser.process(app);
 
 	// Set OpenGL version
@@ -155,12 +137,12 @@ int main(int argc, char** argv)
 				dir.mkpath(path + "/" + subpath);
 				olddir.setPath(oldpath + "/" + subpath);
 
-				QStringList subdirs = olddir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
+				const QStringList subdirs = olddir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
 				for (const QString& subdir : subdirs) {
 					old_dirs.append(subpath + "/" + subdir);
 				}
 
-				QStringList files = olddir.entryList(QDir::Files);
+				const QStringList files = olddir.entryList(QDir::Files);
 				for (const QString& file : files) {
 					QFile::rename(olddir.absoluteFilePath(file), path + "/" + subpath + "/" + file);
 				}
@@ -192,7 +174,7 @@ int main(int argc, char** argv)
 		old_dirs += (path + "/images/thumbnails/small/");
 		for (int i = 0; i < old_dirs.count(); ++i) {
 			dir.setPath(old_dirs.at(i));
-			QStringList entries = dir.entryList(QDir::Files);
+			const QStringList entries = dir.entryList(QDir::Files);
 			for (const QString& info : entries) {
 				dir.remove(info);
 			}
@@ -222,7 +204,7 @@ int main(int argc, char** argv)
 	// Reset tracking of the game currently open
 	settings.remove("OpenGame");
 
-	app.createWindow();
+	app.createWindow(parser.positionalArguments());
 
 	return app.exec();
 }
