@@ -1,24 +1,11 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2010, 2011, 2014 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2014 Graeme Gott <graeme@gottcode.org>
 
-#ifndef NEW_GAME_TAB_H
-#define NEW_GAME_TAB_H
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
+
+#ifndef TETZLE_NEW_GAME_TAB_H
+#define TETZLE_NEW_GAME_TAB_H
 
 class TagManager;
 class ToolBarList;
@@ -37,7 +24,7 @@ class NewGameTab : public QWidget
 	Q_OBJECT
 
 public:
-	NewGameTab(const QStringList& files, QDialog* parent = 0);
+	explicit NewGameTab(const QStringList& files, QDialog* parent = nullptr);
 
 	void addImages(const QStringList& images);
 
@@ -46,7 +33,7 @@ signals:
 	void newGame(const QString& image, int difficulty);
 
 protected:
-	virtual void hideEvent(QHideEvent* event);
+	void hideEvent(QHideEvent* event) override;
 
 private slots:
 	void accept();
@@ -77,4 +64,4 @@ private:
 	QPushButton* m_accept_button;
 };
 
-#endif
+#endif // TETZLE_NEW_GAME_TAB_H
