@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2010, 2011, 2012, 2014, 2016 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2016 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "piece.h"
 
@@ -28,14 +15,14 @@
 //-----------------------------------------------------------------------------
 
 Piece::Piece(const QPoint& pos, int rotation, const QList<Tile*>& tiles, Board* board)
-	: m_board(board),
-	m_pos(pos),
-	m_tiles(tiles),
-	m_shadow(tiles),
-	m_rotation(0),
-	m_depth(2),
-	m_selected(true),
-	m_changed(false)
+	: m_board(board)
+	, m_pos(pos)
+	, m_tiles(tiles)
+	, m_shadow(tiles)
+	, m_rotation(0)
+	, m_depth(2)
+	, m_selected(true)
+	, m_changed(false)
 {
 	updateTiles();
 	updateShadow();
@@ -94,7 +81,7 @@ QPoint Piece::randomPoint() const
 
 void Piece::attachNeighbors()
 {
-	auto neighbors = m_neighbors;
+	const auto neighbors = m_neighbors;
 	for (Piece* piece : neighbors) {
 		if (piece->m_rotation != m_rotation) {
 			continue;
@@ -123,9 +110,9 @@ void Piece::attachNeighbors()
 void Piece::findNeighbors(const QList<Piece*>& pieces)
 {
 	// Find neighbor tiles
-	static QList<QPoint> deltas = QList<QPoint>() << QPoint(-1,0) << QPoint(1,0) << QPoint(0,-1) << QPoint(0,1);
+	static const QList<QPoint> deltas = QList<QPoint>() << QPoint(-1,0) << QPoint(1,0) << QPoint(0,-1) << QPoint(0,1);
 	QList<QPoint> tiles;
-	for (Tile* tile : m_shadow) {
+	for (Tile* tile : qAsConst(m_shadow)) {
 		QPoint pos(tile->column(), tile->row());
 		for (const QPoint& delta : deltas) {
 			QPoint neighbor = pos + delta;
@@ -137,7 +124,7 @@ void Piece::findNeighbors(const QList<Piece*>& pieces)
 
 	// Find neighbor pieces
 	for (Piece* piece : pieces) {
-		for (const QPoint& tile : tiles) {
+		for (const QPoint& tile : qAsConst(tiles)) {
 			if (piece->containsTile(tile.x(), tile.y())) {
 				m_neighbors.insert(piece);
 				break;
@@ -304,7 +291,7 @@ void Piece::attach(Piece* piece)
 	m_neighbors += piece->m_neighbors;
 	m_neighbors.remove(piece);
 	m_neighbors.remove(this);
-	for (Piece* neighbor : m_neighbors) {
+	for (Piece* neighbor : qAsConst(m_neighbors)) {
 		neighbor->m_neighbors.remove(piece);
 		neighbor->m_neighbors.insert(this);
 	}
