@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2010, 2011, 2014, 2016 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2016 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "tag_manager.h"
 
@@ -32,8 +19,8 @@
 //-----------------------------------------------------------------------------
 
 TagManager::TagManager(QWidget* parent)
-	: QWidget(parent),
-	m_all_images_item(0)
+	: QWidget(parent)
+	, m_all_images_item(0)
 {
 	// Add filter
 	m_filter = new ToolBarList(this);
@@ -63,7 +50,7 @@ TagManager::TagManager(QWidget* parent)
 
 	QSettings file(Path::image("tags"), QSettings::IniFormat);
 	file.beginGroup("Tags");
-	QStringList tags = file.childKeys();
+	const QStringList tags = file.childKeys();
 	QStringList images;
 	QDir folder(Path::images(), "*.*");
 	for (const QString& tag : tags) {
@@ -236,7 +223,7 @@ void TagManager::removeTag()
 	// Remove item
 	QString tag = item->text();
 	delete item;
-	item = 0;
+	item = nullptr;
 	m_remove_action->setEnabled(m_filter->count() > 1);
 
 	// Remove tag
@@ -257,7 +244,7 @@ void TagManager::currentTagChanged(QListWidgetItem* item)
 
 void TagManager::tagChanged(QListWidgetItem* item)
 {
-	if (item == 0) {
+	if (!item) {
 		return;
 	}
 
