@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2008, 2010, 2011, 2014, 2015, 2016, 2017, 2018, 2019, 2020 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2008-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "window.h"
 
@@ -45,7 +32,7 @@
 //-----------------------------------------------------------------------------
 
 Window::Window(const QStringList& files)
-	: m_board(0)
+	: m_board(nullptr)
 {
 	setAcceptDrops(true);
 	resize(640, 480);
@@ -77,27 +64,27 @@ Window::Window(const QStringList& files)
 	QMenu* menu;
 
 	menu = menuBar()->addMenu(tr("&Game"));
-	QAction* choose_action = menu->addAction(tr("&Choose..."), this, SLOT(chooseGame()));
+	QAction* choose_action = menu->addAction(tr("&Choose..."), this, [this]() { chooseGame(QStringList()); });
 	choose_action->setShortcuts(QList<QKeySequence>() << QKeySequence::New << QKeySequence::Open);
 	menu->addSeparator();
-	QAction* retrieve_pieces_action = menu->addAction(tr("&Retrieve Pieces"), m_board, SLOT(retrievePieces()), tr("Ctrl+R"));
+	QAction* retrieve_pieces_action = menu->addAction(tr("&Retrieve Pieces"), m_board, &Board::retrievePieces, tr("Ctrl+R"));
 	retrieve_pieces_action->setEnabled(false);
 	connect(m_board, &Board::retrievePiecesAvailable, retrieve_pieces_action, &QAction::setEnabled);
 	menu->addSeparator();
-	QAction* quit_action = menu->addAction(tr("&Quit"), this, SLOT(close()), QKeySequence::Quit);
+	QAction* quit_action = menu->addAction(tr("&Quit"), this, &Window::close, QKeySequence::Quit);
 	quit_action->setMenuRole(QAction::QuitRole);
 
 	menu = menuBar()->addMenu(tr("&View"));
-	QAction* zoom_in_action = menu->addAction(tr("Zoom &In"), m_board, SLOT(zoomIn()), tr("+"));
+	QAction* zoom_in_action = menu->addAction(tr("Zoom &In"), m_board, &Board::zoomIn, tr("+"));
 	zoom_in_action->setEnabled(false);
 	connect(m_board, &Board::zoomInAvailable, zoom_in_action, &QAction::setEnabled);
-	QAction* zoom_out_action = menu->addAction(tr("Zoom &Out"), m_board, SLOT(zoomOut()), tr("-"));
+	QAction* zoom_out_action = menu->addAction(tr("Zoom &Out"), m_board, &Board::zoomOut, tr("-"));
 	zoom_out_action->setEnabled(false);
 	connect(m_board, &Board::zoomOutAvailable, zoom_out_action, &QAction::setEnabled);
-	m_zoom_fit_action = menu->addAction(tr("Best &Fit"), m_board, SLOT(zoomFit()));
+	m_zoom_fit_action = menu->addAction(tr("Best &Fit"), m_board, &Board::zoomFit);
 	m_zoom_fit_action->setEnabled(false);
 	menu->addSeparator();
-	m_toggle_overview_action = menu->addAction(tr("Show O&verview"), m_board, SLOT(toggleOverview()), tr("Tab"));
+	m_toggle_overview_action = menu->addAction(tr("Show O&verview"), m_board, &Board::toggleOverview, tr("Tab"));
 	m_toggle_overview_action->setCheckable(true);
 	m_toggle_overview_action->setEnabled(false);
 	connect(m_board, &Board::overviewToggled, m_toggle_overview_action, &QAction::setChecked);
@@ -113,15 +100,15 @@ Window::Window(const QStringList& files)
 #endif
 
 	menu = menuBar()->addMenu(tr("&Settings"));
-	menu->addAction(tr("&Appearance..."), this, SLOT(showAppearance()));
-	menu->addAction(tr("&Language..."), this, SLOT(setLocale()));
+	menu->addAction(tr("&Appearance..."), this, &Window::showAppearance);
+	menu->addAction(tr("&Language..."), this, &Window::setLocale);
 
 	menu = menuBar()->addMenu(tr("&Help"));
-	menu->addAction(tr("&Controls"), this, SLOT(showControls()), QKeySequence::HelpContents);
+	menu->addAction(tr("&Controls"), this, &Window::showControls, QKeySequence::HelpContents);
 	menu->addSeparator();
-	QAction* about_action = menu->addAction(tr("&About"), this, SLOT(showAbout()));
+	QAction* about_action = menu->addAction(tr("&About"), this, &Window::showAbout);
 	about_action->setMenuRole(QAction::AboutRole);
-	QAction* about_qt_action = menu->addAction(tr("About &Qt"), qApp, SLOT(aboutQt()));
+	QAction* about_qt_action = menu->addAction(tr("About &Qt"), qApp, &QApplication::aboutQt);
 	about_qt_action->setMenuRole(QAction::AboutQtRole);
 
 	// Restore geometry
@@ -269,7 +256,7 @@ void Window::showControls()
 	layout->addWidget(new QLabel(tr("Move mouse or W,A,D,S"), &dialog), 6, 2, Qt::AlignLeft | Qt::AlignVCenter);
 
 	QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Close, Qt::Horizontal, &dialog);
-	connect(buttons, SIGNAL(rejected()), &dialog, SLOT(reject()));
+	connect(buttons, &QDialogButtonBox::rejected, &dialog, &QDialog::reject);
 	layout->addWidget(buttons, 8, 0, 1, 3);
 
 	dialog.exec();
@@ -282,7 +269,7 @@ void Window::showAbout()
 	QMessageBox::about(this, tr("About Tetzle"), QString("<p align='center'><big><b>%1 %2</b></big><br/>%3<br/><small>%4<br/>%5</small></p>")
 		.arg(tr("Tetzle"), QCoreApplication::applicationVersion(),
 			tr("A jigsaw puzzle with tetrominoes for pieces"),
-			tr("Copyright &copy; 2008-%1 Graeme Gott").arg("2020"),
+			tr("Copyright &copy; 2008-%1 Graeme Gott").arg("2021"),
 			tr("Released under the <a href=%1>GPL 3</a> license").arg("\"http://www.gnu.org/licenses/gpl.html\""))
 	);
 }
