@@ -459,5 +459,9 @@ Există jocuri salvate care folosesc această imagine, care vor fi, de asemenea,
         <source>version</source>
         <translation>versiunea</translation>
     </message>
+    <message>
+        <source>Images to add to the choose game dialog.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
